@@ -36,8 +36,11 @@ def nargs(f):
         return None
 
 
+do_curry = set((toolz.map, toolz.filter))
+
 def should_curry(f):
-    return callable(f) and nargs(f) and nargs(f) > 1
+    return (callable(f) and nargs(f) and nargs(f) > 1
+            or f in do_curry)
 
 
 d = dict((name, curry(f) if '__' not in name and should_curry(f) else f)
